from holon.HolonicAgent import HolonicAgent

class KanbanDetect(HolonicAgent):
    def __init__(self, cfg):
        super().__init__(cfg)


